@@ -34,10 +34,10 @@ class PopplerExtractor : public ExtractorPlugin
     Q_INTERFACES(KFileMetaData::ExtractorPlugin)
 
 public:
-    PopplerExtractor(QObject* parent = 0);
+    explicit PopplerExtractor(QObject* parent = nullptr);
 
-    virtual QStringList mimetypes() const;
-    virtual void extract(ExtractionResult* result);
+    QStringList mimetypes() const override;
+    void extract(ExtractionResult* result) override;
 
 private:
     QString parseFirstPage(Poppler::Document* pdfDoc, const QString& fileUrl);
